@@ -93,7 +93,7 @@ int gnutls_random_art (gnutls_random_art_t type,
 void
 gnutls_dh_set_prime_bits (gnutls_session_t session, unsigned int bits)
 {
-  if (bits <= 512) _gnutls_audit_log(session, "Note that the security level of the Diffie-Hellman key exchange has been lowered to %u bits and this may allow decryption of the session data\n", bits);
+  if (bits < 512) _gnutls_audit_log(session, "Note that the security level of the Diffie-Hellman key exchange has been lowered to %u bits and this may allow decryption of the session data\n", bits);
   session->internals.dh_prime_bits = bits;
 }
 
